'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _rimraf = require('rimraf');

var _rimraf2 = _interopRequireDefault(_rimraf);

var _Logger = require('../Logger');

var _Logger2 = _interopRequireDefault(_Logger);

var _compareReports = require('./compareReports');

var _compareReports2 = _interopRequireDefault(_compareReports);

var _domRunner = require('../domRunner');

var _domRunner2 = _interopRequireDefault(_domRunner);

var _generateDevSha = require('../generateDevSha');

var _generateDevSha2 = _interopRequireDefault(_generateDevSha);

var _uploadReport = require('../uploadReport');

var _uploadReport2 = _interopRequireDefault(_uploadReport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function indent(str) {
  return str.replace(/^/gm, ' ');
}

exports.default = async function devCommand(config, { only }) {
  const { apiKey, apiSecret, endpoint, project } = config;
  let baselineSha;
  const logger = new _Logger2.default();
  _rimraf2.default.sync(config.tmpdir);
  _mkdirp2.default.sync(config.tmpdir);
  (0, _domRunner2.default)(config, {
    only,
    onReady: async snaps => {
      const sha = (0, _generateDevSha2.default)();
      logger.start(`Preparing report (${sha})...`);
      const { url } = await (0, _uploadReport2.default)({
        snaps,
        sha,
        endpoint,
        apiKey,
        apiSecret,
        project
      });
      logger.success();
      logger.info(`View results at ${url}`);

      if (baselineSha) {
        logger.start('Comparing with baseline report...');
        const result = await (0, _compareReports2.default)(baselineSha, sha, { apiKey, apiSecret, endpoint, project }, {});
        logger.success();
        logger.info(`\n${indent(result.summary)}`);
      } else {
        baselineSha = sha;
      }
    }
  });
};