'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _rimraf = require('rimraf');

var _rimraf2 = _interopRequireDefault(_rimraf);

var _Logger = require('../Logger');

var _Logger2 = _interopRequireDefault(_Logger);

var _domRunner = require('../domRunner');

var _domRunner2 = _interopRequireDefault(_domRunner);

var _makeRequest = require('../makeRequest');

var _makeRequest2 = _interopRequireDefault(_makeRequest);

var _pageRunner = require('../pageRunner');

var _pageRunner2 = _interopRequireDefault(_pageRunner);

var _remoteRunner = require('../remoteRunner');

var _remoteRunner2 = _interopRequireDefault(_remoteRunner);

var _uploadReport = require('../uploadReport');

var _uploadReport2 = _interopRequireDefault(_uploadReport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = async function runCommand(sha, config, { only, link, message, isAsync }) {
  const logger = new _Logger2.default();
  const { apiKey, apiSecret, endpoint, project, plugins, pages } = config;

  _rimraf2.default.sync(config.tmpdir);
  _mkdirp2.default.sync(config.tmpdir);

  const staticPlugin = plugins.find(plugin => typeof plugin.generateStaticPackage === 'function');
  let result;
  if (pages) {
    result = await (0, _pageRunner2.default)(config, { isAsync });
  } else if (staticPlugin) {
    result = await (0, _remoteRunner2.default)(config, staticPlugin, { isAsync });
  } else {
    result = await (0, _domRunner2.default)(config, { only, isAsync });
  }

  if (isAsync) {
    logger.start(`Creating async report for ${sha}...`);
    const allRequestIds = [];
    result.forEach(item => allRequestIds.push(...item.result));
    const { id } = await (0, _makeRequest2.default)({
      url: `${endpoint}/api/async-reports/${sha}`,
      method: 'POST',
      json: true,
      body: {
        requestIds: allRequestIds,
        link,
        message,
        project
      }
    }, { endpoint, apiKey, apiSecret, maxTries: 3 });

    logger.success();
    logger.info(`Async report id: ${id}`);
  } else {
    logger.start(`Uploading report for ${sha}...`);
    const { url } = await (0, _uploadReport2.default)({
      snaps: result,
      sha,
      endpoint,
      apiKey,
      apiSecret,
      link,
      message,
      project
    });
    logger.success();
    logger.info(`View results at ${url}`);
  }
  logger.info(`Done ${sha}`);
};