'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _requireRelative = require('require-relative');

var _requireRelative2 = _interopRequireDefault(_requireRelative);

var _findTestFiles = require('./findTestFiles');

var _findTestFiles2 = _interopRequireDefault(_findTestFiles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const { VERBOSE = 'false' } = process.env;

exports.default = async function createDynamicEntryPoint({
  setupScript,
  include,
  only,
  type,
  plugins,
  prerender,
  tmpdir,
  rootElementSelector,
  renderWrapperModule,
  asyncTimeout
}) {
  const files = await (0, _findTestFiles2.default)(include);
  const filePartOfOnly = only ? only.split('#')[0] : undefined;
  const fileStrings = files.filter(f => filePartOfOnly ? f.includes(filePartOfOnly) : true).map(file => _path2.default.join(process.cwd(), file)).concat(plugins.map(({ pathToExamplesFile }) => pathToExamplesFile)).filter(Boolean).map(file => `window.happoProcessor.prepare(${JSON.stringify(file)}, require(${JSON.stringify(file)}));`);

  const pathToProcessor = require.resolve('./browser/processor');
  const strings = [`const Processor = require(${JSON.stringify(pathToProcessor)}).default;`, `window.happoProcessor = new Processor(${JSON.stringify({ only, rootElementSelector, asyncTimeout })});`, `window.verbose = '${VERBOSE}' === 'true' ? console.log : () => null;`, 'window.snaps = {};'];
  if (type === 'react') {
    const pathToReactDom = _requireRelative2.default.resolve('react-dom', process.cwd());
    const pathToRW = renderWrapperModule || require.resolve('./renderWrapperReact');
    strings.push(`let renderWrapper = require('${pathToRW}');`, 'renderWrapper = renderWrapper.default || renderWrapper;');
    strings.push(`
      const ReactDOM = require('${pathToReactDom}');
      window.happoRender = (reactComponent, { rootElement, component, variant }) =>
        ReactDOM.render(renderWrapper(reactComponent, { component, variant }), rootElement);

      window.happoCleanup = () => {
        for (const element of document.body.children) {
          ReactDOM.unmountComponentAtNode(element);
        }
      };
    `.trim());
  } else {
    const pathToRW = renderWrapperModule || require.resolve('./renderWrapper');
    strings.push(`let renderWrapper = require('${pathToRW}');`, 'renderWrapper = renderWrapper.default || renderWrapper;');
    strings.push(`
      window.happoRender = (html, { rootElement, component, variant }) => {
        rootElement.innerHTML = renderWrapper(html, { component, variant });
        return rootElement;
      };

      window.happoCleanup = () => {};
    `.trim());
  }

  if (setupScript) {
    strings.push(`require('${setupScript}');`);
  }
  strings.push(...fileStrings);
  if (!prerender) {
    const pathToRemoteRenderer = require.resolve('./browser/remoteRenderer');
    strings.push(`require('${pathToRemoteRenderer}');`);
  }
  strings.push('window.onBundleReady && window.onBundleReady();');
  const entryFile = _path2.default.join(tmpdir, 'happo-entry.js');

  const content = strings.join('\n');
  if (VERBOSE === 'true') {
    console.log(`Created webpack entry file with the following content:\n\n${content}\n\n`);
  }
  _fs2.default.writeFileSync(entryFile, content);
  return { entryFile, numberOfFilesProcessed: fileStrings.length };
};