'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _requestPromiseNative = require('request-promise-native');

var _requestPromiseNative2 = _interopRequireDefault(_requestPromiseNative);

var _requireRelative = require('require-relative');

var _requireRelative2 = _interopRequireDefault(_requireRelative);

var _Logger = require('./Logger');

var _Logger2 = _interopRequireDefault(_Logger);

var _WrappedError = require('./WrappedError');

var _WrappedError2 = _interopRequireDefault(_WrappedError);

var _DEFAULTS = require('./DEFAULTS');

var defaultConfig = _interopRequireWildcard(_DEFAULTS);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function load(pathToConfigFile) {
  try {
    let userConfig = (0, _requireRelative2.default)(pathToConfigFile, process.cwd());
    // await if the config is a function, async or not
    if (typeof userConfig === 'function') {
      userConfig = await userConfig();
    }
    return _extends({}, defaultConfig, userConfig);
  } catch (e) {
    // We only check for the default config file here, so that a missing custom
    // config path isn't ignored.
    if (e.message && /Cannot find.*\.happo\.js/.test(e.message)) {
      return defaultConfig;
    }
    throw new Error(e);
  }
}

async function getPullRequestSecret({ endpoint }, env) {
  const { secret } = await (0, _requestPromiseNative2.default)({
    url: `${endpoint}/api/pull-request-token`,
    method: 'POST',
    json: true,
    body: {
      prUrl: env.CHANGE_URL
    }
  });

  return secret;
}

exports.default = async function loadUserConfig(pathToConfigFile, env = process.env) {
  const { CHANGE_URL, HAPPO_CONFIG_FILE } = env;

  if (HAPPO_CONFIG_FILE) {
    pathToConfigFile = HAPPO_CONFIG_FILE;
  }

  const config = await load(pathToConfigFile);
  if (!config.apiKey || !config.apiSecret) {
    if (!CHANGE_URL) {
      throw new Error('You need an `apiKey` and `apiSecret` in your config. ' + 'To obtain one, go to https://happo.io/settings');
    }
    try {
      // Reassign api tokens to temporary ones provided for the PR
      new _Logger2.default().info('No `apiKey` or `apiSecret` found in config. Falling back to pull-request authentication.');
      config.apiKey = CHANGE_URL;
      config.apiSecret = await getPullRequestSecret(config, env);
    } catch (e) {
      throw new _WrappedError2.default('Failed to obtain temporary pull-request token', e);
    }
  }
  if (!config.targets || Object.keys(config.targets).length === 0) {
    throw new Error('You need at least one target defined under `targets`. ' + 'See https://github.com/happo/happo.io#targets for more info.');
  }
  const defaultKeys = Object.keys(defaultConfig);
  const usedKeys = Object.keys(config);
  usedKeys.forEach(key => {
    if (!defaultKeys.includes(key)) {
      new _Logger2.default().warn(`Unknown config key used in .happo.js: "${key}"`);
    }
  });
  config.publicFolders.push(config.tmpdir);
  config.plugins.forEach(({ publicFolders }) => {
    if (publicFolders) {
      config.publicFolders.push(...publicFolders);
    }
  });
  return config;
};