'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _asyncRetry = require('async-retry');

var _asyncRetry2 = _interopRequireDefault(_asyncRetry);

var _jsonwebtoken = require('jsonwebtoken');

var _jsonwebtoken2 = _interopRequireDefault(_jsonwebtoken);

var _requestPromiseNative = require('request-promise-native');

var _requestPromiseNative2 = _interopRequireDefault(_requestPromiseNative);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = async function makeRequest(requestAttributes, { apiKey, apiSecret, maxTries = 0 }) {
  return (0, _asyncRetry2.default)(async () => {
    const signed = _jsonwebtoken2.default.sign({ key: apiKey }, apiSecret, {
      header: { kid: apiKey }
    });
    const result = await (0, _requestPromiseNative2.default)(Object.assign({
      gzip: true,
      auth: {
        bearer: signed
      }
    }, requestAttributes));
    return result;
  }, {
    retries: maxTries,
    onRetry: () => {
      const { method, url } = requestAttributes;
      console.warn(`Failed ${method} ${url}. Retrying...`);
    }
  });
};