'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _perf_hooks = require('perf_hooks');

var _Logger = require('./Logger');

var _Logger2 = _interopRequireDefault(_Logger);

var _constructReport = require('./constructReport');

var _constructReport2 = _interopRequireDefault(_constructReport);

var _loadCSSFile = require('./loadCSSFile');

var _loadCSSFile2 = _interopRequireDefault(_loadCSSFile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = async function remoteRunner({ apiKey, apiSecret, endpoint, targets, plugins, stylesheets }, { generateStaticPackage }, { isAsync }) {
  const logger = new _Logger2.default();
  try {
    logger.info('Generating static package...');
    const staticPackage = await generateStaticPackage();
    const targetNames = Object.keys(targets);
    const tl = targetNames.length;
    const cssBlocks = await Promise.all(stylesheets.map(_loadCSSFile2.default));
    plugins.forEach(({ css }) => cssBlocks.push(css || ''));
    logger.info(`Generating screenshots in ${tl} target${tl > 1 ? 's' : ''}...`);
    const outerStartTime = _perf_hooks.performance.now();
    const results = await Promise.all(targetNames.map(async name => {
      const startTime = _perf_hooks.performance.now();
      const result = await targets[name].execute({
        targetName: name,
        asyncResults: isAsync,
        staticPackage,
        apiKey,
        apiSecret,
        endpoint,
        globalCSS: cssBlocks.join('').replace(/\n/g, '')
      });
      logger.start(`  - ${name}`, { startTime });
      logger.success();
      return { name, result };
    }));
    logger.start(undefined, { startTime: outerStartTime });
    logger.success();
    if (isAsync) {
      return results;
    }
    return (0, _constructReport2.default)(results);
  } catch (e) {
    logger.fail();
    throw e;
  }
};