'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-line import/no-extraneous-dependencies

class ErrorBoundary extends _react2.default.Component {
  constructor(props) {
    super(props);
    this.state = {};
  }

  static getDerivedStateFromError(error) {
    return { error };
  }

  componentDidCatch(error) {
    const { component, variant } = this.props;
    console.error(`Caught error while rendering component "${component}", variant "${variant}"`);
    console.error(error);
  }

  render() {
    const { error } = this.state;
    const { component, variant, children } = this.props;
    if (error) {
      return _react2.default.createElement('pre', {
        style: {
          whiteSpace: 'pre-wrap',
          wordBreak: 'break-all',
          fontSize: 'small'
        }
      }, `Error when rendering component "${component}", variant "${variant}"\n\n${error.stack}`);
    }

    return children;
  }
} // This is the default, render wrapper. If you're looking to provide your
// own, it might look something like this:
// ```
// /* In React */
// export default (component) => <Wrapper>{component}</Wrapper>
// ```
// ```
// /* In a plain-js project */
// export default (html) => '<div>' + html + '</div>';
//

exports.default = (result, { component, variant }) => _react2.default.createElement(ErrorBoundary, { component, variant }, result);